@@ -2,12 +2,16 @@ import re
 
 import pandas as pd
 
+from sdrf_pipelines.openms.unimod import UnimodDatabase
+
 
 class OpenMS:
 
   def __init__(self) -> None:
     super().__init__()
     self.warnings = dict()
+    self._unimod_database = UnimodDatabase()
+
 
   def openms_ify_mods(self, sdrf_mods):
     oms_mods = list()
@@ -19,6 +23,11 @@ class OpenMS:
       name = re.search("NT=(.+?)(;|$)", m).group(1)
       name = name.capitalize()
 
+      accession = re.search("AC=(.+?)(;|$)", m).group(1)
+      ptm = self._unimod_database.get_by_accession(accession)
+      if ptm != None:
+        name = ptm.get_name()
+
       # workaround for missing PP in some sdrf TODO: fix in sdrf spec?
       if re.search("PP=(.+?)[;$]", m) is None:
         pp = "Anywhere"
@@ -225,6 +234,10 @@ class OpenMS:
 
     ##################### only label-free supported right now
 
+
+
+
+
     # output of search settings
     f = open("openms.tsv", "w+")
     open_ms_search_settings_header = ["URI", "Filename", "FixedModifications", "VariableModifications", "Label",
@@ -282,12 +295,15 @@ class OpenMS:
         else:
           out = raw
 
+        # MSstats BioReplicate column needs to be different for samples from different conditions.
+        # so we can't just use the technical replicate identifier in sdrf but use the sample identifer
+        MSstatsBioReplicate = sample
         if legacy:
           f.write(fraction_group + "\t" + file2fraction[
-            raw] + "\t" + out + "\t" + label + "\t" + sample + "\t" + condition + "\t" + replicate + "\n")
+            raw] + "\t" + out + "\t" + label + "\t" + sample + "\t" + condition + "\t" + MSstatsBioReplicate + "\n")
         else:
           f.write(fraction_group + "\t" + file2fraction[
-            raw] + "\t" + out + "\t" + label + "\t" + condition + "\t" + replicate + "\n")
+            raw] + "\t" + out + "\t" + label + "\t" + condition + "\t" + MSstatsBioReplicate + "\n")
       f.close()
     else:  # two table format
       openms_file_header = ["Fraction_Group", "Fraction", "Spectra_Filepath", "Label", "Sample"]
@@ -343,8 +359,12 @@ class OpenMS:
         else:
           condition = file2combined_factors[raw]
 
+        # MSstats BioReplicate column needs to be different for samples from different conditions.
+        # so we can't just use the technical replicate identifier in sdrf but use the sample identifer
+        MSstatsBioReplicate = sample
+
         if sample not in sample_row_written:
-          f.write(sample + "\t" + condition + "\t" + replicate + "\n")
+          f.write(sample + "\t" + condition + "\t" + MSstatsBioReplicate + "\n")
           sample_row_written.append(sample)
 
     f.close()
